summaryrefslogtreecommitdiffstats
path: root/models/repo_unit.go
diff options
context:
space:
mode:
Diffstat (limited to 'models/repo_unit.go')
-rw-r--r--models/repo_unit.go9
1 files changed, 3 insertions, 6 deletions
diff --git a/models/repo_unit.go b/models/repo_unit.go
index 1553fa771d..cb647fd406 100644
--- a/models/repo_unit.go
+++ b/models/repo_unit.go
@@ -106,12 +106,9 @@ func (r *RepoUnit) BeforeSet(colName string, val xorm.Cell) {
}
}
-// AfterSet is invoked from XORM after setting the value of a field of this object.
-func (r *RepoUnit) AfterSet(colName string, _ xorm.Cell) {
- switch colName {
- case "created_unix":
- r.Created = time.Unix(r.CreatedUnix, 0).Local()
- }
+// AfterLoad is invoked from XORM after setting the values of all fields of this object.
+func (r *RepoUnit) AfterLoad() {
+ r.Created = time.Unix(r.CreatedUnix, 0).Local()
}
// Unit returns Unit